% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inspect_types.R
\name{inspect_types}
\alias{inspect_types}
\title{Summary and comparison of column types}
\usage{
inspect_types(df1, df2 = NULL, show_plot = FALSE)
}
\arguments{
\item{df1}{A dataframe.}

\item{df2}{An optional second dataframe for comparison.}

\item{show_plot}{(Deprecated) Logical flag indicating whether a plot should be shown.
Superseded by the function \code{show_plot()} and will be dropped in a future version.}
}
\value{
A tibble summarising the count and percentage of different 
column types for one or a pair of data frames.
}
\description{
For a single dataframe, summarise the column types.  If two 
dataframes are supplied, compare column type composition of both dataframes.
}
\details{
For a \strong{single dataframe}, the tibble returned contains the columns: \cr
\itemize{
  \item \code{type}, a character vector containing the column types in \code{df1}.
  \item \code{cnt}, integer counts of each type.
  \item \code{pcnt}, the percentage of all columns with each type.
  \item \code{col_name}, the names of columns with each type. \cr
}
For a \strong{pair of dataframes}, the tibble returned contains the columns: \cr
\itemize{
  \item \code{type}, a character vector containing the column types in 
  \code{df1} and \code{df2}.
  \item \code{cnt_1}, \code{cnt_2}, pair of integer columns containing counts of each type - 
  in each of \code{df1} and \code{df2}.
  \item \code{pcnt_1}, \code{pcnt_2}, pair of columns containing the percentage of 
  columns with each type - the data frame name are appended.
}
For a \strong{grouped dataframe}, the tibble returned is as for a single dataframe, but where 
the first \code{k} columns are the grouping columns.  There will be as many rows in the result 
as there are unique combinations of the grouping variables.
}
\examples{
# Load dplyr for starwars data & pipe
library(dplyr)

# Single dataframe summary
inspect_types(starwars)

# Paired dataframe comparison
inspect_types(starwars, starwars[1:20, ])
}
\seealso{
\code{\link{show_plot}}
}
\author{
Alastair Rushworth
}
